        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 27 <strong>control</strong><br>0,1,3,4,6,8,9,10,13,18,20,21,23,25,27,28,30,33,35,36,38,40,41,43,47,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <br>2,5,7,11,12,14,15,16,17,19,22,24,26,29,31,32,34,37,39,42,44,45,46,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 27 <strong>control</strong><br>0,1,3,4,6,8,9,10,13,18,20,21,23,25,27,28,30,33,35,36,38,40,41,43,47,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <br>2,5,7,11,12,14,15,16,17,19,22,24,26,29,31,32,34,37,39,42,44,45,46,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 27 <strong>control</strong><br>0,1,3,4,6,8,9,10,13,18,20,21,23,25,27,28,30,33,35,36,38,40,41,43,47,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <br>2,5,7,11,12,14,15,16,17,19,22,24,26,29,31,32,34,37,39,42,44,45,46,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 27 <strong>control</strong><br>0,1,3,4,6,8,9,10,13,18,20,21,23,25,27,28,30,33,35,36,38,40,41,43,47,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <br>2,5,7,11,12,14,15,16,17,19,22,24,26,29,31,32,34,37,39,42,44,45,46,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>20</strong> miembros: 27 <strong>control</strong><br>0,1,3,4,6,8,9,10,13,18,20,21,23,25,27,28,30,33,35,36,38,40,41,43,47,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260810 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <br>2,5,7,11,12,14,15,16,17,19,22,24,26,29,31,32,34,37,39,42,44,45,46,48';}
}
